@@ -1,6 +1,8 @@
 import pytest
-from sqlalchemy_api_handler import ApiHandler
-from sqlalchemy_api_handler.utils.human_ids import dehumanize, NonDehumanizableId
+from sqlalchemy_api_handler import ApiHandler, as_dict
+from sqlalchemy_api_handler.utils.human_ids import dehumanize, \
+                                                   humanize, \
+                                                   NonDehumanizableId
 
 from tests.conftest import clean_database
 from tests.test_utils.db import Model
@@ -13,7 +15,7 @@ from tests.test_utils.models.user_offerer import UserOfferer
 
 class SaveTest:
     @clean_database
-    def test_for_valid_one_to_many_relationship(self):
+    def test_for_valid_one_to_many_relationship(self, app):
         # Given
         offer = Offer(name="foo", type="bar")
         stock = Stock(offer=offer, price=1)
@@ -25,7 +27,7 @@ class SaveTest:
         assert stock.offerId == offer.id
 
     @clean_database
-    def test_for_valid_many_to_many_relationship(self):
+    def test_for_valid_many_to_many_relationship(self, app):
         # Given
         offerer = Offerer(name="foo", type="bar")
         user = User(email="bar@gmare.com", publicName="bar")
@@ -40,7 +42,7 @@ class SaveTest:
         assert user_offerer.userId == user.id
 
     @clean_database
-    def test_for_valid_synonym(self):
+    def test_for_valid_synonym(self, app):
         # Given
         job = "foo"
         user = User(
@@ -55,3 +57,20 @@ class SaveTest:
         # Then
         assert user.metier == job
         assert user.job == job
+
+
+    @clean_database
+    def test_for_valid_id_humanized_synonym(self, app):
+        # Given
+        user = User(
+            email="bar@gmare.com",
+            publicName="bar"
+        )
+
+        # When
+        ApiHandler.save(user)
+
+        # Then
+        user_dict = as_dict(user)
+        humanized_id = humanize(user.user_id)
+        assert user_dict['id'] == humanized_id
